summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoTextIterator.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kotext/KoTextIterator.h')
-rw-r--r--lib/kotext/KoTextIterator.h27
1 files changed, 14 insertions, 13 deletions
diff --git a/lib/kotext/KoTextIterator.h b/lib/kotext/KoTextIterator.h
index 40934a18..c2c5fff8 100644
--- a/lib/kotext/KoTextIterator.h
+++ b/lib/kotext/KoTextIterator.h
@@ -19,10 +19,10 @@
#ifndef KOTEXTITERATOR_H
#define KOTEXTITERATOR_H
-#include <qvaluelist.h>
-#include <qstring.h>
-#include <qpair.h>
-#include <qobject.h>
+#include <tqvaluelist.h>
+#include <tqstring.h>
+#include <tqpair.h>
+#include <tqobject.h>
#include <koffice_export.h>
class KoTextParag;
class KoTextObject;
@@ -33,19 +33,20 @@ class KoTextView;
* with many options (from cursor, backwards, in selection).
* @short General purpose paragraph iterator
*/
-class KOTEXT_EXPORT KoTextIterator : public QObject
+class KOTEXT_EXPORT KoTextIterator : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* @param lstObjects list of text objects to iterate over
* @param textView view in which the objects live
* @param options see KFindDialog
*/
- KoTextIterator( const QValueList<KoTextObject *> & lstObjects, KoTextView* textView, int options ) {
+ KoTextIterator( const TQValueList<KoTextObject *> & lstObjects, KoTextView* textView, int options ) {
init( lstObjects, textView, options );
}
- void init( const QValueList<KoTextObject *> & lstObjects, KoTextView* textView, int options );
+ void init( const TQValueList<KoTextObject *> & lstObjects, KoTextView* textView, int options );
/**
* Restart from the beginning - assumes same parameters given to init
@@ -83,7 +84,7 @@ public:
/**
* @return the string at the current position of the iterator
*/
- QString currentText() const;
+ TQString currentText() const;
/**
* @return the string at the current position of the iterator
@@ -106,7 +107,7 @@ public:
* Use this instead of separate calls to currentText and currentStartIndex,
* for performance reasons.
*/
- QPair<int, QString> currentTextAndIndex() const;
+ TQPair<int, TQString> currentTextAndIndex() const;
signals:
/**
@@ -130,10 +131,10 @@ protected slots:
void slotParagraphModified( KoTextParag* parag, int /*ParagModifyType*/, int pos, int length );
private:
// The reason we use a QValueList of pointers instead of QPtrList
// is that having a QPtrListIterator member var can't work, one can't
// initialize it afterwards.
- QValueList<KoTextObject *> m_lstObjects;
+ TQValueList<KoTextObject *> m_lstObjects;
int m_options;
// This is relative to the first textobject in m_lstObjects
@@ -147,7 +148,7 @@ private:
int m_lastIndex;
// Our current position
- QValueList<KoTextObject *>::Iterator m_currentTextObj;
+ TQValueList<KoTextObject *>::Iterator m_currentTextObj;
KoTextParag* m_currentParag;
};
@@ -130,10 +131,10 @@ protected slots:
void slotParagraphModified( KoTextParag* parag, int /*ParagModifyType*/, int pos, int length );
private:
- // The reason we use a QValueList of pointers instead of QPtrList
- // is that having a QPtrListIterator member var can't work, one can't
+ // The reason we use a TQValueList of pointers instead of TQPtrList
+ // is that having a TQPtrListIterator member var can't work, one can't
// initialize it afterwards.